There is demand for also zapping page table entries by drivers in
VM_MIXEDMAP VMAs[1].

Nothing really speaks against supporting VM_MIXEDMAP for driver use. We
just don't want arbitrary drivers to zap in ordinary (non-special) VMAs.

[1] https://lore.kernel.org/r/[email protected]

Signed-off-by: David Hildenbrand (Arm) <[email protected]>
---
 mm/memory.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/mm/memory.c b/mm/memory.c
index f3b7b7e16138..3fe30dc2f179 100644
--- a/mm/memory.c
+++ b/mm/memory.c
@@ -2239,13 +2239,13 @@ void zap_vma_range(struct vm_area_struct *vma, unsigned 
long address,
  * @size: number of bytes to zap
  *
  * This function does nothing when the provided address range is not fully
  * contained in @vma, or when the @vma is not VM_PFNMAP.
  */
 void zap_special_vma_range(struct vm_area_struct *vma, unsigned long address,
                unsigned long size)
 {
        if (!range_in_vma(vma, address, address + size) ||
-                       !(vma->vm_flags & VM_PFNMAP))
+          !(vma->vm_flags & (VM_PFNMAP | VM_MIXEDMAP)))
                return;
 
        zap_vma_range(vma, address, size);
@@ -2239,13 +2239,13 @@ void zap_vma_range(struct vm_area_struct *vma, unsigned 
  *
  * This function does nothing when the provided address range is not fully
- * contained in @vma, or when the @vma is not VM_PFNMAP.
+ * contained in @vma, or when the @vma is not VM_PFNMAP or VM_MIXEDMAP.
  */
 void zap_special_vma_range(struct vm_area_struct *vma, unsigned long address,
-- 
2.43.0


Reply via email to